@@ -290,6 +290,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                 dd_max_retries,
                 {
                     "type": "white_list",
+                    "limit": dd_limits_query
                 },
             )
 
@@ -770,6 +771,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
             create_date=create_date,
             expired_date=expired_date,
             severity=finding.severity.lower(),
+            priority=finding.priority_classification.lower(),
             reason=reason,
         )
 
